.. This is part of the Photini documentation.
   Copyright (C)  2012-19  Jim Easterbrook.
   See the file DOC_LICENSE.txt for copying conditions.

Photini documentation
=====================

Welcome to the documentation of Photini, an easy to use photograph metadata editor.
For a quick introduction to Photini and its features I suggest you read :doc:`the introduction <other/introduction>`.
More detail about its capabilities can be found in :doc:`the user manual <manual/index>`.

.. toctree::
   :maxdepth: 2

   other/introduction
   other/installation
   manual/index
   other/workflow
   other/localisation
   misc/index
   other/reading

Copyright (C)  2012-19  Jim Easterbrook.

Permission is granted to copy, distribute and/or modify this document under the terms of the GNU Free Documentation License, Version 1.3 or any later version published by the Free Software Foundation; with no Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts.
A copy of the license is included in the section entitled "GNU Free Documentation License".
